/*
 * Copyright 2016 - 2022 Gary Talent (gary@drinkingtea.net). All rights reserved.
 */

#pragma once

#include <ox/claw/claw.hpp>
#include <ox/std/string.hpp>

#include "context.hpp"

namespace nostalgia::core {

ox::String getClipboardText(class Context *ctx) noexcept;

void setClipboardText(class Context *ctx, const ox::String &text) noexcept;

void setClipboardObject([[maybe_unused]] class Context *ctx, [[maybe_unused]] auto *obj) noexcept {
#ifndef OX_BARE_METAL
	auto [buff, err] = ox::writeClaw(obj);
	if (err) {
		oxLogError(err);
		return;
	}
	ctx->clipboard = std::move(buff);
#endif
}

ox::Error getClipboardObject([[maybe_unused]] class Context *ctx, [[maybe_unused]] auto *obj) noexcept {
#ifndef OX_BARE_METAL
	return ox::readClaw<decltype(*obj)>(ctx->clipboard).moveTo(obj);
#else
	return OxError(0);
#endif
}

template<typename T>
ox::Result<T> getClipboardObject([[maybe_unused]] class Context *ctx) noexcept {
#ifndef OX_BARE_METAL
	return ox::readClaw<T>(ctx->clipboard);
#else
	return OxError(0);
#endif
}

}
